aboutsummaryrefslogtreecommitdiff
path: root/build/cli/rule.cxx
diff options
context:
space:
mode:
authorBoris Kolpackov <boris@codesynthesis.com>2015-07-01 09:11:31 +0200
committerBoris Kolpackov <boris@codesynthesis.com>2015-07-01 09:11:31 +0200
commit17b3a78696f0b1fd6f0f60d53ec568cf3b9e32b4 (patch)
treef54f92e5066e1a97a070af248931316cd76b61c3 /build/cli/rule.cxx
parent70af0087d8efb3f2f7dc9ffdf2568419913f16da (diff)
Cleanup group "see through" design
Diffstat (limited to 'build/cli/rule.cxx')
-rw-r--r--build/cli/rule.cxx10
1 files changed, 2 insertions, 8 deletions
diff --git a/build/cli/rule.cxx b/build/cli/rule.cxx
index 09ef4f3..2d001c4 100644
--- a/build/cli/rule.cxx
+++ b/build/cli/rule.cxx
@@ -163,15 +163,9 @@ namespace build
//
inject_parent_fsdir (a, t);
// Search and match prerequisites.
//
- switch (a.operation ())
- {
- case default_id:
- case update_id: search_and_match (a, t); break;
- case clean_id: search_and_match (a, t, t.dir); break;
- default: assert (false); // We didn't register for this.
- }
+ search_and_match_prerequisite_members (a, t);
switch (a)
{
@@ -163,15 +163,9 @@ namespace build
//
inject_parent_fsdir (a, t);
- // Search and match prerequisites.
+ // Search and match prerequisite members.
//